import { ChangeDetectorRef, Component, EventEmitter, Input, Output } from '@angular/core';
import { ToastrService } from 'ngx-toastr';
import { EmployeeModel, MyEmployeeModel } from 'src/app/shared/model/employee.model';
import { MyUserModel, UserModel } from 'src/app/shared/model/user.model';
import { EmployeeService } from 'src/app/shared/services/employee.service';
import { FileService } from 'src/app/shared/services/file.service';
import { UserService } from 'src/app/shared/services/user.service';

@Component({
  selector: 'app-user-settings',
  templateUrl: './user-settings.component.html',
  styleUrls: ['./user-settings.component.scss']
})
export class UserSettingsComponent {
  selectedFile: File | null = null;
  selectedFileName: string = 'กรุณาเลือกไฟล์';
  currentModal: 'add' | 'edit' = "add"

  user: { loading: boolean, select: UserModel, dataList: { check: boolean, data: UserModel }[] } = { loading: false, select: new MyUserModel(), dataList: [] }
  employee: { loading: boolean, select: EmployeeModel, dataList: { check: boolean, data: EmployeeModel }[] } = { loading: false, select: new MyEmployeeModel(), dataList: [] }
  constructor(private toastr: ToastrService,
    private cdr: ChangeDetectorRef,
    private userService: UserService,
    private employeeService: EmployeeService,
    private fileService: FileService) { }
  ngOnInit(): void {
    this.getUserList()
    this.getEmployeeList()
  }
  getEmployeeList() {
    this.employee.loading = true
    this.employeeService.getList().subscribe(response => {
      this.employee.dataList = response.map(x => ({ check: false, data: new MyEmployeeModel(x) }))
      this.employee.loading = false
      this.cdr.detectChanges()
    }, error => {
      this.employee.loading = false
      this.cdr.detectChanges()
    })

  }
  getUserList() {
    this.user.loading = true
    this.userService.getList().subscribe(response => {
      this.user.dataList = response.map(x => ({ check: false, data: new MyUserModel(x) }))
      this.user.loading = false
      this.cdr.detectChanges()
    }, error => {
      this.user.loading = false
      this.cdr.detectChanges()
    })
  }

  selectData(filed: string, data: any) {
    (this as any)[filed] = data
  }
  onFileSelected(event: any) {
    this.selectedFile = event.target.files.length > 0 ? event.target.files[0] : null;
    this.selectedFileName = this.selectedFile?.name || "กรุณาเลือกไฟล์"
  }
  uploadFile() {
    if (!this.selectedFile) {
      alert('กรุณาเลือกไฟล์ก่อนอัปโหลด')
      return
    }
    const formData = new FormData();
    formData.append('file', this.selectedFile);
    this.user.loading = true
    this.fileService.upload(formData, 'mbu1').subscribe({
      next: response => {
        if (response.success) {
          this.showAlert(response.message, 'success')
        } else {
          this.showAlert(response.message, 'error')
          this.user.loading = false
        }
      }, error: error => {
        this.showAlert(error.message, 'error')
        this.user.loading = false
      }
    })
  }
  selectUser() {

  }
  downloadFile() {
    const fileName = 'IMPORT_USER.xlsx'
    this.fileService.download(fileName).subscribe({
      next: response => {
        const url = window.URL.createObjectURL(response);
        const a = document.createElement("a");
        a.href = url;
        a.download = fileName;
        document.body.appendChild(a);
        a.click();
        document.body.removeChild(a);
        window.URL.revokeObjectURL(url);
      }, error: error => {
        this.showAlert(error.message, 'error')
      }
    })

  }

  showAlert(text: string, type: 'success' | 'error') {
    this.toastr[type](text, 'แจ้งเตือน', {
      timeOut: 3000,
      positionClass: 'toast-top-right',
    })
  }
}
